/******************************************************************************
   FATURAMENTO COMISSARIA
   
   Procedure para Apurao de NFs por Voo (Gera uma NF nova a cada voo). 
   
   * A srie das NFs de servio ser 'A' (portanto esta srie deve estar 
     cadastrada no sistema para que no de erro de PK). 
   
   * A srie das demais NF-s ser a srie passada pelo parmetro P_CDSERIE
*******************************************************************************/   

CREATE OR REPLACE PROCEDURE APURAC_VOO(
   P_FILIAL    IN FILIAL.CDFILIAL%TYPE,
   P_FILIPROC  IN FILIAL.CDFILIAL%TYPE,
   P_CDCIA     IN COMPANHIA.CDCIA%TYPE,
   P_DTFECHAME IN DATE,
   P_DTINIAPUR IN DATE,
   P_DTFIMAPUR IN DATE,
   P_CDSERIE   IN SERIENF.CDSERIE%TYPE,
   P_IDTPIJURTRAN IN TRANSPORT.IDTPIJURTRAN%TYPE,
   P_NRINSJURTRAN IN TRANSPORT.NRINSJURTRAN%TYPE,
   P_NRVOO        IN VARCHAR2 DEFAULT 'T',
   P_IDAGRUPSERV  IN SERVPLANO.IDTIPSCBOSP%TYPE DEFAULT 'N',
   P_NRAPURACFAT  IN NOTAFISCAL.NRAPURACFAT%TYPE)

AS

   V_NRSEQITPROD   NUMBER;

   V_CDCLIENTE     COMPANHIA.CDCLIENTE%TYPE;

   V_NRLANCTONF    VARCHAR(20);

   V_NRLANCTONFAP  VARCHAR(20); 

   V_VRCOTDOLAR    TRAB_APURAC.VRCOTDOLARAP%TYPE;
   V_NRVOO         TRAB_APURAC.NRVOOAP%TYPE;
   V_CDTRECHO      TRAB_APURAC.CDTRECHOAP%TYPE;
   V_CDFISCOPER    TRAB_APURAC.CDFISCOPERAP%TYPE;
   V_IDSERVICO     TRAB_APURAC.IDSERVICOAP%TYPE;
   V_CDSERIE       SERIENF.CDSERIE%TYPE;

   V_CDEMPRESA     FILIAL.CDEMPRESA%TYPE;
   V_CDINSCMUNI    FILIAL.CDINSCMUNI%TYPE;
   V_CDINSCESTA    FILIAL.CDINSCESTA%TYPE;

   V_IDTPIJURCLIE  CLIENTE.IDTPIJURCLIE%TYPE;
   V_NRINSJURCLIE  CLIENTE.NRINSJURCLIE%TYPE;

   V_NOVANOTA      VARCHAR2(01);

   V_VRDESCDEL     DELIVERY.VRDESCDEL%TYPE;
   V_VRDESCSRV     DELIVERY.VRDESCSRV%TYPE;

   V_VRINDICE      MOVINDICE.VRINDICE%TYPE;
   V_VRUNITITEM    ITEMPRODUTO.VRUNITITEM%TYPE;

   V_IDCONMAXITEM  SERIENF.IDCONMAXITEM%TYPE;
   V_NRMAXITNF     SERIENF.NRMAXITNF%TYPE;
   V_NRMAXSERVNF   SERIENF.NRMAXSERVNF%TYPE;

   V_NRORDEMISPR   TRAB_APURAC.NRORDEMIS%TYPE;
   V_NRORDEMISSV   TRAB_APURAC.NRORDEMIS%TYPE;
   V_NRORDEMIS     TRAB_APURAC.NRORDEMIS%TYPE;

   V_NRCOUNTPR     TRAB_APURAC.NRORDEMIS%TYPE;
   V_NRCOUNTSV     TRAB_APURAC.NRORDEMIS%TYPE;

   V_VRTAXAAERO    ITEMPRODUTO.VRUNITITEM%TYPE;

   V_VRTAXAAEME    ITEMPRODUTO.VRUNITITEM%TYPE;

   V_IDMUNIUTCONVNFE MUNICIPIO.IDMUNIUTCONVNFE%TYPE;
   V_IDEMPUTILIZANFE PARAMEMPRESA.IDEMPUTILIZANFE%TYPE;

   V_IDPRODSERVAP  TRAB_APURAC.IDPRODSERVAP%TYPE;

   V_COUNT_SERVICO NUMBER;
   
   V_CDTIPOOPERVENDA VARCHAR2(2);
BEGIN

   SELECT MAX(CDCLIENTE), MAX(CDTIPOOPERVENDA) 
     INTO V_CDCLIENTE, V_CDTIPOOPERVENDA
   FROM COMPANHIA
   WHERE CDCIA = P_CDCIA;
   
   IF V_CDTIPOOPERVENDA IS NULL THEN
      V_CDTIPOOPERVENDA := '01';
   END IF;

   SELECT MAX(CDEMPRESA), MAX(CDINSCMUNI), MAX(CDINSCESTA)
   INTO V_CDEMPRESA, V_CDINSCMUNI, V_CDINSCESTA
   FROM FILIAL
   WHERE CDFILIAL = P_FILIAL;

   SELECT MAX(IDTPIJURCLIE), MAX(NRINSJURCLIE)
   INTO V_IDTPIJURCLIE, V_NRINSJURCLIE
   FROM CLIENTE
   WHERE CDCLIENTE = V_CDCLIENTE;

   SELECT NVL(NRMAXITNF, 10), NVL(NRMAXSERVNF, 5),
          IDCONMAXITEM
   INTO V_NRMAXITNF, V_NRMAXSERVNF, V_IDCONMAXITEM
   FROM SERIENF
   WHERE CDEMPRESA  = V_CDEMPRESA  AND
         CDINSCESTA = V_CDINSCESTA AND
         CDINSCMUNI = V_CDINSCMUNI AND
         CDSERIE    = P_CDSERIE;

  SELECT NVL(MI.IDMUNIUTCONVNFE, 'N') AS IDMUNIUTCONVNFE, NVL(PE.IDEMPUTILIZANFE, 'N') IDEMPUTILIZANFE
    INTO V_IDMUNIUTCONVNFE, V_IDEMPUTILIZANFE
    FROM EMPRESA EP, MUNICIPIO MI, PARAMEMPRESA PE
   WHERE EP.CDEMPRESA = V_CDEMPRESA
     AND EP.CDEMPRESA = PE.CDEMPRESA(+)
     AND EP.CDPAIS = MI.CDPAIS
     AND EP.SGESTADO = MI.SGESTADO
     AND EP.CDMUNICIPIO = MI.CDMUNICIPIO;

   V_NRLANCTONF := 'X';
   V_CDFISCOPER := 'X';
   V_NRVOO      := 'X';
   V_CDTRECHO   := 'X';
   V_IDSERVICO  := 'X';
   V_VRCOTDOLAR := -1;

   V_NRSEQITPROD := 0;

   V_NOVANOTA := 'X';

   V_VRDESCDEL := 0;
   V_VRDESCSRV := 0;

   V_NRORDEMISPR := 0;
   V_NRORDEMISSV := V_NRMAXITNF;

   V_NRCOUNTPR   := 0;
   V_NRCOUNTSV   := 0;

   FOR CURS_APVOO IN
      (SELECT CDCIAAP, NRVOOAP, CDTRECHOAP, IDTIPMANUALAP, CDFISCOPERAP, CDSUFXCFOPAP,
              IDSERVICOAP, CDSERVICOAP, CDPRODUTOAP, DSSERVFATUAP, VRPUREASERVAP, VRPUDOLSERVAP,
              VRCOTDOLARAP, IDPRODSERVAP, QTPROPPRODINIAP, QTPROPPRODFINAP
       FROM TRAB_APURAC
       WHERE CDCIAAP       = P_CDCIA  AND
             CDFILIALAP    = P_FILIPROC AND
             NRAPURACFATAP = P_NRAPURACFAT

       GROUP BY CDCIAAP, NRVOOAP, CDTRECHOAP, VRCOTDOLARAP, IDTIPMANUALAP, CDFISCOPERAP, CDSUFXCFOPAP,
                IDSERVICOAP, CDSERVICOAP, CDPRODUTOAP, DSSERVFATUAP, VRPUREASERVAP, VRPUDOLSERVAP,
                IDPRODSERVAP, QTPROPPRODINIAP, QTPROPPRODFINAP
       ORDER BY
          CDCIAAP, NRVOOAP, CDTRECHOAP, IDTIPMANUALAP, CDFISCOPERAP, CDSUFXCFOPAP,
          IDSERVICOAP, CDSERVICOAP, CDPRODUTOAP, DSSERVFATUAP, VRPUREASERVAP, VRPUDOLSERVAP,
          VRCOTDOLARAP, IDPRODSERVAP) LOOP

      IF CURS_APVOO.IDPRODSERVAP = 'S' THEN
         V_NRCOUNTSV := V_NRCOUNTSV + 1;
         IF V_NRCOUNTSV > V_NRMAXSERVNF THEN
            V_NRORDEMISSV := V_NRORDEMISSV + V_NRMAXITNF + 1;
            V_NRCOUNTSV   := 1;
         ELSE
            V_NRORDEMISSV := V_NRORDEMISSV + 1;
         END IF;
         V_NRORDEMIS := V_NRORDEMISSV;
      ELSE
         V_NRCOUNTPR := V_NRCOUNTPR + 1;
         IF V_IDCONMAXITEM <> 'N' THEN
            IF V_NRCOUNTPR > V_NRMAXITNF THEN
               V_NRORDEMISPR := V_NRORDEMISPR + V_NRMAXSERVNF + 1;
               V_NRCOUNTPR   := 1;
            ELSE
               V_NRORDEMISPR := V_NRORDEMISPR + 1;
            END IF;
         ELSE
            V_NRORDEMISPR := V_NRORDEMISPR + V_NRMAXSERVNF + 1;
            V_NRCOUNTPR   := 1;
         END IF;
         V_NRORDEMIS := V_NRORDEMISPR;
      END IF;

      UPDATE TRAB_APURAC
      SET NRORDEMIS = V_NRORDEMIS
      WHERE CDCIAAP               = CURS_APVOO.CDCIAAP       AND
            CDFILIALAP            = P_FILIPROC                 AND
            NRAPURACFATAP         = P_NRAPURACFAT            AND
            CDSERVICOAP           = CURS_APVOO.CDSERVICOAP   AND
            NRVOOAP               = CURS_APVOO.NRVOOAP       AND
            CDTRECHOAP            = CURS_APVOO.CDTRECHOAP    AND
            CDPRODUTOAP           = CURS_APVOO.CDPRODUTOAP   AND
            IDTIPMANUALAP         = CURS_APVOO.IDTIPMANUALAP AND
            IDPRODSERVAP          = CURS_APVOO.IDPRODSERVAP  AND
            DSSERVFATUAP          = CURS_APVOO.DSSERVFATUAP  AND
            VRCOTDOLARAP          = CURS_APVOO.VRCOTDOLARAP  AND
            IDSERVICOAP           = CURS_APVOO.IDSERVICOAP   AND
            (NVL(CDFISCOPERAP,0)  = NVL(CURS_APVOO.CDFISCOPERAP,0))  AND
            (NVL(CDSUFXCFOPAP,0)  = NVL(CURS_APVOO.CDSUFXCFOPAP,0))  AND
            (NVL(VRPUREASERVAP,0) = NVL(CURS_APVOO.VRPUREASERVAP,0)) AND
            (NVL(VRPUDOLSERVAP,0) = NVL(CURS_APVOO.VRPUDOLSERVAP,0));
   END LOOP;

   FOR CURS_APVOO IN
      (SELECT CDCIAAP, NRVOOAP, CDTRECHOAP, CDFISCOPERAP, CDSUFXCFOPAP,
              IDSERVICOAP, CDSERVICOAP, CDPRODUTOAP, DSSERVFATUAP, VRPUREASERVAP, VRPUDOLSERVAP,
              SUM(NRQTDESERVAP) NRTOTASERVAP,  NVL(SUM(VRDESCDELAP),0) VRDESCDELAP,
              IDTIPMANUALAP, VRCOTDOLARAP, IDPRODSERVAP, NRORDEMIS, QTPROPPRODINIAP, QTPROPPRODFINAP
       FROM TRAB_APURAC
       WHERE CDCIAAP       = P_CDCIA  AND
             CDFILIALAP    = P_FILIPROC AND
             NRAPURACFATAP = P_NRAPURACFAT AND
             ((INSTR(P_NRVOO, '_'||NRVOOAP) > 0) OR (P_NRVOO = 'T'))

       GROUP BY CDCIAAP, NRVOOAP, CDTRECHOAP, NRORDEMIS, VRCOTDOLARAP, IDTIPMANUALAP, CDFISCOPERAP, CDSUFXCFOPAP,
                IDSERVICOAP, CDSERVICOAP, CDPRODUTOAP, DSSERVFATUAP, VRPUREASERVAP, VRPUDOLSERVAP,
                IDPRODSERVAP, QTPROPPRODINIAP, QTPROPPRODFINAP
       ORDER BY
          CDCIAAP, NRVOOAP, CDTRECHOAP, CDFISCOPERAP, CDSUFXCFOPAP,
          IDSERVICOAP, CDSERVICOAP, CDPRODUTOAP, DSSERVFATUAP, VRPUREASERVAP, VRPUDOLSERVAP,
          IDTIPMANUALAP, VRCOTDOLARAP, IDPRODSERVAP, NRORDEMIS) LOOP

        --Se A Delivery for Nacional 
       IF CURS_APVOO.IDTIPMANUALAP = '1' THEN
          
           /************************************************************************************************************************
            Gera uma Nova Nota fiscal em um dos casos:
          
              1. Estiver apurando o primeiro servio (Primeiro dado do Cursor)
              2. Estiver um novo Voo (No faturamento por Voo, uma nova NF  gerada a cada Voo, com os servios do mesmo)
              3. For um Produto e tiver alcanado o mximo de Produtos em uma NF, e controlar quantidade maxima de Intens na NF
              4. For um Servio e tiver alcanado o mximo de Servios em uma NF, e controlar quantidade maxima de Intens na NF
              5. Separa as NFs de Produto e de Servios quando a empresa utilizar NF-E (Tela Parametros de DFS) e o municpio no deve
                 da empresa no deve utilizar convnio de NF-E (campo "Convnio NF-E" da tela "Municpio")
              
           *************************************************************************************************************************/
          IF (CURS_APVOO.CDFISCOPERAP <> V_CDFISCOPER) OR
             (((CURS_APVOO.NRVOOAP <> V_NRVOO) OR (CURS_APVOO.CDTRECHOAP <> V_CDTRECHO)) AND
             (P_IDAGRUPSERV = 'N')) OR
             ((((V_NRCOUNTPR = V_NRMAXITNF)   AND (CURS_APVOO.IDPRODSERVAP = 'P')) OR
             ((V_NRCOUNTSV = V_NRMAXSERVNF) AND (CURS_APVOO.IDPRODSERVAP = 'S'))) AND
             (V_IDCONMAXITEM = 'S')) OR
             ((CURS_APVOO.IDPRODSERVAP <> V_IDPRODSERVAP) AND (V_IDMUNIUTCONVNFE = 'N') AND
             (V_IDEMPUTILIZANFE = 'S')) THEN


             IF (((CURS_APVOO.NRVOOAP <> V_NRVOO) OR (CURS_APVOO.CDTRECHOAP <> V_CDTRECHO)) AND
                 (P_IDAGRUPSERV = 'N')) THEN
                SELECT NVL(MAX(VRDESCDELAP),0), NVL(MAX(VRDESCSRVAP),0)
                INTO V_VRDESCDEL, V_VRDESCSRV
                FROM TRAB_APURAC
                WHERE (CDCIAAP = P_CDCIA)               AND
                      (CDFILIALAP    = P_FILIPROC)        AND
                      (NRAPURACFATAP = P_NRAPURACFAT)   AND
                      ((((CURS_APVOO.NRVOOAP = NRVOOAP) AND (CURS_APVOO.CDTRECHOAP = CDTRECHOAP)) AND
                       (P_IDAGRUPSERV = 'N')) OR
                      ((CURS_APVOO.CDFISCOPERAP <> CDFISCOPERAP) AND (P_IDAGRUPSERV = 'S'))) AND
                      ((VRDESCDELAP <> 0) OR (VRDESCSRVAP <> 0));
             END IF;

             V_NOVANOTA  := ' ';
             V_NRCOUNTPR := 0;
             V_NRCOUNTSV := 0;
  
            /*************************************************
               A pedido da Sky Chefs, quando for uma NF com 
               Servios, deve conter a Srie 'A'. Portanto,
               a srie de cdigo 'A' deve estar cadastrada 
               na tela "Srie de Documentos Fiscais de Sada".
               
               Devido a uma Customizao no aprovada, este
               parmetro teve que ser passado fixo no cdigo,
               a pedido da prpria Sky Chefs.
             **************************************************/
             IF CURS_APVOO.IDPRODSERVAP = 'S' THEN
                V_CDSERIE := 'A';
             ELSE
                V_CDSERIE := P_CDSERIE;
             END IF;

             /* a procedure novo_codigo gera o novo sequencial e tambem
                confirma a incluso da nota anterior, pois existe um COMMIT
                dentro da novo_codigo */

             NOVO_CODIGO('LANCNF/FILIAL' || P_FILIPROC,V_NRLANCTONF);
             V_NRLANCTONF  := SUBSTR(V_NRLANCTONF, 11, 10);

             V_NRSEQITPROD := 0;

             V_CDFISCOPER  := CURS_APVOO.CDFISCOPERAP;
             V_NRVOO       := CURS_APVOO.NRVOOAP;
             V_CDTRECHO    := CURS_APVOO.CDTRECHOAP;
             V_IDSERVICO   := CURS_APVOO.IDSERVICOAP;
             V_IDPRODSERVAP := CURS_APVOO.IDPRODSERVAP;

             INSERT INTO NOTAFISCAL (CDFILIAL, NRLANCTONF, CDEMPRESA,
                                     CDINSCESTA, CDINSCMUNI, CDFILIEMIT,
                                     CDFILIRECE, IDTPIJURNF, NRINSJURNF,
                                     CDFORNECED, CDCLIENTE, IDERROS, IDAVISOS,
                                     IDBLOQUEADO, IDDOCFISCAL, IDDOCFINANC,
                                     NRNOTAFISC, DTENTRSAID,
                                     VRPRODUTOS, VRNOTAFISC, DTINIAPUFISC,
                                     DTAPROVACAO, CDOPERAPRO, DTCONTABIL,
                                     NRPLACAVEIC, SGUFVEIC, IDPGTOFRETE,
                                     DSQTDEVOLU, DSESPECVOLU, DSMARCAVOLU,
                                     DSNUMEVOLU, VRPBRUTOVOLU, VRPLIQUVOLU,
                                     IDENTRSAIDOP, CDTIPOOPER, CDSERIE, IDTPIJURTRAN,
                                     NRINSJURTRAN, VRTTMOEDESTR, IDSTATUS,
                                     IDSISTEMA, IDDOCFATUR, NRAPURACFAT, IDORIGDESTNF)
             VALUES (P_FILIPROC, V_NRLANCTONF, V_CDEMPRESA,
                     V_CDINSCESTA, V_CDINSCMUNI, P_FILIAL,
                     NULL, V_IDTPIJURCLIE, V_NRINSJURCLIE,
                     NULL, V_CDCLIENTE, NULL, NULL,
                     'N', 'N', 'N',
                     ' ', P_DTFECHAME,
                     0, 0, P_DTINIAPUR,
                     NULL, NULL, NULL,
                     NULL, NULL, NULL,
                     NULL, NULL, NULL,
                     NULL, 0, 0,
                     'S', V_CDTIPOOPERVENDA, V_CDSERIE, P_IDTPIJURTRAN,
                     P_NRINSJURTRAN, 0, 'P', 'FAC', 'S', P_NRAPURACFAT, 'C');
          END IF;

          V_NRSEQITPROD := V_NRSEQITPROD + 1;

          INSERT INTO ITEMPRODUTO (CDFILIAL, NRSEQITPROD,
                                   CDPRODUTO, CDPRODEMIS,
                                   DSPRODEMIS, IDATUVRESTOQ, QTITEMPROD,
                                   VRUNITITEM, VRDESCITEM,
                                   VRTOTAITEM,
                                   VRCONTITEM, VRBRUTITEM, VRITMOEDESTR,
                                   IDCONFORITEM, NRLANCTONF, CDFISOPEITEM,
                                   CDSUFXCFOPPR,
                                   IDERROSITEM, IDAVISOSITEM,
                                   QTPROPPRODINI, QTPROPPRODFIN)
          VALUES (P_FILIPROC, LPAD(TO_CHAR(V_NRSEQITPROD),4,'0'),
                  CURS_APVOO.CDPRODUTOAP, CURS_APVOO.IDTIPMANUALAP||CURS_APVOO.CDSERVICOAP,
                  CURS_APVOO.DSSERVFATUAP, 'N', CURS_APVOO.NRTOTASERVAP,
                  CURS_APVOO.VRPUREASERVAP, 0,
                  ROUND(CURS_APVOO.NRTOTASERVAP * CURS_APVOO.VRPUREASERVAP,2),
                  ROUND(CURS_APVOO.NRTOTASERVAP * CURS_APVOO.VRPUREASERVAP,2),
                  ROUND(CURS_APVOO.NRTOTASERVAP * CURS_APVOO.VRPUREASERVAP,2), 0,
                  'N', V_NRLANCTONF, CURS_APVOO.CDFISCOPERAP,
                  CURS_APVOO.CDSUFXCFOPAP, '00000','00000',
                  CURS_APVOO.QTPROPPRODINIAP, CURS_APVOO.QTPROPPRODFINAP);

         UPDATE TRAB_APURAC
         SET NRLANCTONFAP = V_NRLANCTONF
         WHERE CDCIAAP        = CURS_APVOO.CDCIAAP       AND
               CDFILIALAP     = P_FILIPROC               AND
               NRAPURACFATAP  = P_NRAPURACFAT            AND
               NRVOOAP        = CURS_APVOO.NRVOOAP       AND
               CDTRECHOAP     = CURS_APVOO.CDTRECHOAP    AND
               CDSERVICOAP    = CURS_APVOO.CDSERVICOAP   AND
               CDPRODUTOAP    = CURS_APVOO.CDPRODUTOAP   AND
               IDTIPMANUALAP  = CURS_APVOO.IDTIPMANUALAP AND
               DSSERVFATUAP   = CURS_APVOO.DSSERVFATUAP  AND
               (NVL(CDFISCOPERAP,0)  = NVL(CURS_APVOO.CDFISCOPERAP,0))  AND
               (NVL(CDSUFXCFOPAP,0)  = NVL(CURS_APVOO.CDSUFXCFOPAP,0))  AND
               (NVL(VRPUREASERVAP,0) = NVL(CURS_APVOO.VRPUREASERVAP,0)) AND
               NRLANCTONFAP IS NULL;

         IF CURS_APVOO.IDPRODSERVAP = 'S' THEN
            V_NRCOUNTSV := V_NRCOUNTSV + 1;
         ELSE
            V_NRCOUNTPR := V_NRCOUNTPR + 1;
         END IF;
      
      --Se A Delivery for Internacional (Faturamento em Dolar)  
      ELSIF CURS_APVOO.IDTIPMANUALAP  = '2' THEN
      
         /************************************************************************************************************************
            Gera uma Nova Nota fiscal em um dos casos:
          
              1. Estiver apurando o primeiro servio (Primeiro dado do Cursor)
              2. For um novo Voo (Na apurao por Voo, gera uma nova NF para cada voo, com os servios do mesmo)
              3. A cotao do dolar mudar de uma linha do cursor para a outra
              4. For um Produto e tiver alcanado o mximo de Produtos em uma NF, e controlar quantidade maxima de Intens na NF
              5. For um Servio e tiver alcanado o mximo de Servios em uma NF, e controlar quantidade maxima de Intens na NF
              6. Separa as NFs de Produto e de Servios quando a empresa utilizar NF-E (Tela Parametros de DFS) e o municpio no deve
                 da empresa no deve utilizar convnio de NF-E (campo "Convnio NF-E" da tela "Municpio")
              
           *************************************************************************************************************************/
         IF (CURS_APVOO.CDFISCOPERAP <> V_CDFISCOPER) OR
            (((CURS_APVOO.NRVOOAP <> V_NRVOO) OR (CURS_APVOO.CDTRECHOAP <> V_CDTRECHO)) AND
            (P_IDAGRUPSERV = 'N')) OR
            (CURS_APVOO.VRCOTDOLARAP <> V_VRCOTDOLAR) OR
            ((((V_NRCOUNTPR = V_NRMAXITNF)   AND (CURS_APVOO.IDPRODSERVAP = 'P')) OR
            ((V_NRCOUNTSV = V_NRMAXSERVNF) AND (CURS_APVOO.IDPRODSERVAP = 'S'))) AND
            (V_IDCONMAXITEM = 'S')) OR
            ((CURS_APVOO.IDPRODSERVAP <> V_IDPRODSERVAP) AND (V_IDMUNIUTCONVNFE = 'N') AND
            (V_IDEMPUTILIZANFE = 'S')) THEN

            IF (((CURS_APVOO.NRVOOAP <> V_NRVOO) OR (CURS_APVOO.CDTRECHOAP <> V_CDTRECHO)) AND
                (P_IDAGRUPSERV = 'N')) THEN

               SELECT NVL(MAX(VRDESCDELAP),0), NVL(MAX(VRDESCSRVAP),0)
               INTO V_VRDESCDEL, V_VRDESCSRV
               FROM TRAB_APURAC
               WHERE CDCIAAP = P_CDCIA                 AND
                     CDFILIALAP    = P_FILIPROC          AND
                     NRAPURACFATAP = P_NRAPURACFAT     AND
                     ((((CURS_APVOO.NRVOOAP = NRVOOAP) AND (CURS_APVOO.CDTRECHOAP = CDTRECHOAP)) AND
                      (P_IDAGRUPSERV = 'N')) OR
                     ((CURS_APVOO.CDFISCOPERAP <> CDFISCOPERAP) AND (P_IDAGRUPSERV = 'S'))) AND
                     ((VRDESCDELAP <> 0) OR (VRDESCSRVAP <> 0));
            END IF;

            /*************************************************
               A pedido da Sky Chefs, quando for uma NF com 
               Servios, deve conter a Srie 'A'. Portanto,
               a srie de cdigo 'A' deve estar cadastrada 
               na tela "Srie de Documentos Fiscais de Sada".
               
               Devido a uma Customizao no aprovada, este
               parmetro teve que ser passado fixo no cdigo,
               a pedido da prpria Sky Chefs.
            **************************************************/
            IF CURS_APVOO.IDPRODSERVAP = 'S' THEN
                V_CDSERIE := 'A';
             ELSE
                V_CDSERIE := P_CDSERIE;
             END IF;

            V_NOVANOTA  := ' ';
            V_NRCOUNTPR := 0;
            V_NRCOUNTSV := 0;
            /* a procedure novo_codigo gera o novo sequencial e tambem
               confirma a incluso da nota anterior, pois existe um COMMIT
               dentro da novo_codigo */

            NOVO_CODIGO('LANCNF/FILIAL' || P_FILIPROC,V_NRLANCTONF);
             V_NRLANCTONF  := SUBSTR(V_NRLANCTONF, 11, 10);

            V_NRSEQITPROD := 0;

            V_CDFISCOPER  := CURS_APVOO.CDFISCOPERAP;
            V_NRVOO       := CURS_APVOO.NRVOOAP;
            V_CDTRECHO    := CURS_APVOO.CDTRECHOAP;
            V_VRCOTDOLAR  := CURS_APVOO.VRCOTDOLARAP;
            V_IDSERVICO   := CURS_APVOO.IDSERVICOAP;
            V_IDPRODSERVAP := CURS_APVOO.IDPRODSERVAP;

            INSERT INTO NOTAFISCAL (CDFILIAL, NRLANCTONF, CDEMPRESA,
                                    CDINSCESTA, CDINSCMUNI, CDFILIEMIT,
                                    CDFILIRECE, IDTPIJURNF, NRINSJURNF,
                                    CDFORNECED, CDCLIENTE, IDERROS, IDAVISOS,
                                    IDBLOQUEADO, IDDOCFISCAL, IDDOCFINANC,
                                    NRNOTAFISC, DTENTRSAID,
                                    VRPRODUTOS, VRNOTAFISC, DTINIAPUFISC,
                                    DTAPROVACAO, CDOPERAPRO, DTCONTABIL,
                                    NRPLACAVEIC, SGUFVEIC, IDPGTOFRETE,
                                    DSQTDEVOLU, DSESPECVOLU, DSMARCAVOLU,
                                    DSNUMEVOLU, VRPBRUTOVOLU, VRPLIQUVOLU,
                                    IDENTRSAIDOP, CDTIPOOPER, CDSERIE, IDTPIJURTRAN,
                                    NRINSJURTRAN, VRTTMOEDESTR, IDSTATUS,
                                    IDSISTEMA, IDDOCFATUR, NRAPURACFAT, IDORIGDESTNF)
            VALUES (P_FILIPROC, V_NRLANCTONF, V_CDEMPRESA,
                    V_CDINSCESTA, V_CDINSCMUNI, P_FILIAL,
                    NULL, V_IDTPIJURCLIE, V_NRINSJURCLIE,
                    NULL, V_CDCLIENTE, NULL, NULL,
                    'N', 'N', 'N',
                    ' ', P_DTFECHAME,
                    0, 0, P_DTINIAPUR,
                    NULL, NULL, NULL,
                    NULL, NULL, NULL,
                    NULL, NULL, NULL,
                    NULL, 0, 0,
                    'S', V_CDTIPOOPERVENDA, V_CDSERIE, P_IDTPIJURTRAN,
                    P_NRINSJURTRAN, 0, 'P', 'FAC', 'S', P_NRAPURACFAT, 'C');
         END IF;

         V_NRSEQITPROD := V_NRSEQITPROD + 1;

         V_VRINDICE := CURS_APVOO.VRCOTDOLARAP;

         IF V_VRINDICE IS NULL THEN
            raise_application_error(-20501, 'IndFi_NCad', True);
         END IF;

         V_VRUNITITEM := CURS_APVOO.VRPUDOLSERVAP * V_VRINDICE;

         INSERT INTO ITEMPRODUTO (CDFILIAL, NRSEQITPROD,
                                  CDPRODUTO, CDPRODEMIS,
                                  DSPRODEMIS, IDATUVRESTOQ, QTITEMPROD,
                                  VRUNITITEM, VRDESCITEM,
                                  VRTOTAITEM,
                                  VRCONTITEM, VRBRUTITEM, VRITMOEDESTR,
                                  IDCONFORITEM, NRLANCTONF, CDFISOPEITEM,
                                  CDSUFXCFOPPR,
                                  IDERROSITEM, IDAVISOSITEM,
                                  QTPROPPRODINI, QTPROPPRODFIN)
         VALUES (P_FILIPROC, LPAD(TO_CHAR(V_NRSEQITPROD),4,'0'),
                 CURS_APVOO.CDPRODUTOAP, CURS_APVOO.IDTIPMANUALAP||CURS_APVOO.CDSERVICOAP,
                 CURS_APVOO.DSSERVFATUAP, 'N', CURS_APVOO.NRTOTASERVAP,
                 V_VRUNITITEM, 0,
                 ROUND(CURS_APVOO.NRTOTASERVAP * V_VRUNITITEM,2),
                 ROUND(CURS_APVOO.NRTOTASERVAP * V_VRUNITITEM,2),
                 ROUND(CURS_APVOO.NRTOTASERVAP * V_VRUNITITEM,2),
                 ROUND(CURS_APVOO.NRTOTASERVAP * CURS_APVOO.VRPUDOLSERVAP,2),
                 'N', V_NRLANCTONF, CURS_APVOO.CDFISCOPERAP,
                 CURS_APVOO.CDSUFXCFOPAP, '00000','00000',
                 CURS_APVOO.QTPROPPRODINIAP, CURS_APVOO.QTPROPPRODFINAP);

        UPDATE TRAB_APURAC
        SET NRLANCTONFAP = V_NRLANCTONF
        WHERE CDCIAAP        = CURS_APVOO.CDCIAAP       AND
              CDFILIALAP     = P_FILIPROC                 AND
              NRAPURACFATAP  = P_NRAPURACFAT            AND
              CDSERVICOAP    = CURS_APVOO.CDSERVICOAP   AND
              CDPRODUTOAP    = CURS_APVOO.CDPRODUTOAP   AND
              IDTIPMANUALAP  = CURS_APVOO.IDTIPMANUALAP AND
              NRVOOAP        = CURS_APVOO.NRVOOAP       AND
              CDTRECHOAP     = CURS_APVOO.CDTRECHOAP    AND
              DSSERVFATUAP   = CURS_APVOO.DSSERVFATUAP  AND
              (NVL(VRCOTDOLARAP,0)  = NVL(CURS_APVOO.VRCOTDOLARAP,0))  AND
              (NVL(CDFISCOPERAP,0)  = NVL(CURS_APVOO.CDFISCOPERAP,0))  AND
              (NVL(CDSUFXCFOPAP,0)  = NVL(CURS_APVOO.CDSUFXCFOPAP,0))  AND
              (NVL(VRPUDOLSERVAP,0) = NVL(CURS_APVOO.VRPUDOLSERVAP,0)) AND
              NRLANCTONFAP IS NULL;

         IF CURS_APVOO.IDPRODSERVAP = 'S' THEN
            V_NRCOUNTSV := V_NRCOUNTSV + 1;
         ELSE
            V_NRCOUNTPR := V_NRCOUNTPR + 1;
         END IF;
      END IF;
   END LOOP;


   /* RETORNA VALOR DA TAXA POR VOO E TRECHO*/
   FOR C_TAXAAEROPORTO IN
     (SELECT CDCIAAP, NRVOOAP, CDTRECHOAP, IDTIPMANUALAP, SUM(NVL(VRTXAERORAP, 0)) AS VRTXAERORAP, SUM(NVL(VRTXAERODAP, 0)) AS VRTXAERODAP
        FROM TRAB_APURAC
       WHERE CDCIAAP = P_CDCIA
         AND CDFILIALAP = P_FILIPROC
         AND NRAPURACFATAP = P_NRAPURACFAT
      GROUP BY CDCIAAP, NRVOOAP, CDTRECHOAP, IDTIPMANUALAP) LOOP

      /*-----------------------------------------------
         Dentre as NFs geradas durante a apurao,
         busca a mais recente que contiver "Servios"
         (Handling, por exemplo).
      -----------------------------------------------*/

      SELECT COUNT(1)
        INTO V_COUNT_SERVICO
      FROM TRAB_APURAC
       WHERE CDCIAAP = C_TAXAAEROPORTO.CDCIAAP
         AND CDFILIALAP = P_FILIPROC
         AND NRVOOAP = C_TAXAAEROPORTO.NRVOOAP
         AND CDTRECHOAP = C_TAXAAEROPORTO.CDTRECHOAP
         AND NRAPURACFATAP = P_NRAPURACFAT
         AND IDPRODSERVAP = 'S';

      /*************************************************************************
         se V_NRLANCTONFAP estiver vazio, no foi gerada nenhuma NF com servios,
         portanto uma nova NF de vservios deve ser criada para a incluso da
         taxa de aeroporto.
      **************************************************************************/
      IF (V_COUNT_SERVICO > 0) THEN

         NOVO_CODIGO('LANCNF/FILIAL' || P_FILIPROC,V_NRLANCTONF);
         V_NRLANCTONF  := SUBSTR(V_NRLANCTONF, 11, 10);

         INSERT INTO NOTAFISCAL (CDFILIAL, NRLANCTONF, CDEMPRESA,
                                 CDINSCESTA, CDINSCMUNI, CDFILIEMIT,
                                 CDFILIRECE, IDTPIJURNF, NRINSJURNF,
                                 CDFORNECED, CDCLIENTE, IDERROS, IDAVISOS,
                                 IDBLOQUEADO, IDDOCFISCAL, IDDOCFINANC,
                                 NRNOTAFISC, DTENTRSAID,
                                 VRPRODUTOS, VRNOTAFISC, DTINIAPUFISC,
                                 DTAPROVACAO, CDOPERAPRO, DTCONTABIL,
                                 NRPLACAVEIC, SGUFVEIC, IDPGTOFRETE,
                                 DSQTDEVOLU, DSESPECVOLU, DSMARCAVOLU,
                                 DSNUMEVOLU, VRPBRUTOVOLU, VRPLIQUVOLU,
                                 IDENTRSAIDOP, CDTIPOOPER, CDSERIE, IDTPIJURTRAN,
                                 NRINSJURTRAN, VRTTMOEDESTR, IDSTATUS,
                                 IDSISTEMA, IDDOCFATUR, NRAPURACFAT, IDORIGDESTNF)
         VALUES (P_FILIPROC, V_NRLANCTONF, V_CDEMPRESA,
                 V_CDINSCESTA, V_CDINSCMUNI, P_FILIAL,
                 NULL, V_IDTPIJURCLIE, V_NRINSJURCLIE,
                 NULL, V_CDCLIENTE, NULL, NULL,
                 'N', 'N', 'N',
                 ' ', P_DTFECHAME,
                 0, 0, P_DTINIAPUR,
                 NULL, NULL, NULL,
                 NULL, NULL, NULL,
                 NULL, NULL, NULL,
                 NULL, 0, 0,
                 'S', V_CDTIPOOPERVENDA, 'A', P_IDTPIJURTRAN,
                 P_NRINSJURTRAN, 0, 'P', 'FAC', 'S', P_NRAPURACFAT, 'C');

         --Calcula a Taxa de Aeroporto na nova Nota Fiscal de Servios
         CALCULA_TAXAAEROPORTO(P_FILIAL, P_FILIPROC, V_NRLANCTONF, C_TAXAAEROPORTO.IDTIPMANUALAP, C_TAXAAEROPORTO.VRTXAERORAP, C_TAXAAEROPORTO.VRTXAERODAP);

         APURAC_DADOSADIC(P_FILIAL, P_FILIPROC, V_NRLANCTONF, P_CDCIA, C_TAXAAEROPORTO.NRVOOAP, C_TAXAAEROPORTO.CDTRECHOAP,'T',NULL,'T','T','T');

      /*************************************************************************
         se V_NRLANCTONFAP no estiver vazio, o mesmo contm a NF mais recente,
         dentre as geradas nesta Apurao, que contenha servios. Nesta
         NF ser includa a Taxa de Aeroporto.
      **************************************************************************/
      ELSE
         SELECT MAX(NRLANCTONFAP)
           INTO V_NRLANCTONFAP
         FROM TRAB_APURAC
         WHERE CDCIAAP = C_TAXAAEROPORTO.CDCIAAP
           AND CDFILIALAP = P_FILIPROC
           AND NRVOOAP = C_TAXAAEROPORTO.NRVOOAP
           AND CDTRECHOAP = C_TAXAAEROPORTO.CDTRECHOAP
           AND NRAPURACFATAP = P_NRAPURACFAT
           AND IDPRODSERVAP = 'P';

         IF (V_NRLANCTONFAP  IS not NULL) THEN
            --Calcula a Taxa de Aeroporto na NF de servios atual
            CALCULA_TAXAAEROPORTO(P_FILIAL, P_FILIPROC, V_NRLANCTONFAP,C_TAXAAEROPORTO.IDTIPMANUALAP,
                                  C_TAXAAEROPORTO.VRTXAERORAP, C_TAXAAEROPORTO.VRTXAERODAP);
         END IF;
      END IF;
   END LOOP;

   FOR C_CALCULANOTAPROD IN
      (SELECT NRLANCTONF
         FROM NOTAFISCAL
        WHERE CDFILIAL = P_FILIPROC
          AND NRAPURACFAT = P_NRAPURACFAT) LOOP

      CALCULA_DESCONTOS(P_FILIAL, P_FILIPROC, C_CALCULANOTAPROD.NRLANCTONF, P_CDCIA, P_NRAPURACFAT);

      APURAC_FECH(P_FILIAL, P_FILIPROC, C_CALCULANOTAPROD.NRLANCTONF, P_CDCIA, P_DTFECHAME, P_DTINIAPUR, P_DTFIMAPUR);

   END LOOP;
END;
/

-- VERSAO --
BEGIN ATUVEROBJ('APURAC_VOO','5.45.xxx'); END;
/

